@@ -1,23 +1,23 @@
-__version__ = "2.39.1"
+__version__ = "4.1.2"
 default_app_config = "leprikon.apps.LeprikonConfig"
 
 staticfiles_urls = {
-    "leprikon/lib/bootstrap/css/bootstrap-theme.css": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap-theme.css",  # NOQA
-    "leprikon/lib/bootstrap/css/bootstrap.min.css": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap.min.css",  # NOQA
-    "leprikon/lib/bootstrap/css/bootstrap-theme.css.map": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap-theme.css.map",  # NOQA
-    "leprikon/lib/bootstrap/css/bootstrap.min.css.map": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap.min.css.map",  # NOQA
-    "leprikon/lib/bootstrap/css/bootstrap-theme.min.css": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap-theme.min.css",  # NOQA
-    "leprikon/lib/bootstrap/css/bootstrap.css": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap.css",  # NOQA
-    "leprikon/lib/bootstrap/css/bootstrap-theme.min.css.map": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap-theme.min.css.map",  # NOQA
-    "leprikon/lib/bootstrap/css/bootstrap.css.map": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap.css.map",  # NOQA
-    "leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.svg": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/fonts/glyphicons-halflings-regular.svg",  # NOQA
-    "leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.ttf": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/fonts/glyphicons-halflings-regular.ttf",  # NOQA
-    "leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.eot": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/fonts/glyphicons-halflings-regular.eot",  # NOQA
-    "leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.woff": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/fonts/glyphicons-halflings-regular.woff",  # NOQA
-    "leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.woff2": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/fonts/glyphicons-halflings-regular.woff2",  # NOQA
-    "leprikon/lib/bootstrap/js/bootstrap.min.js": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/js/bootstrap.min.js",  # NOQA
-    "leprikon/lib/bootstrap/js/npm.js": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/js/npm.js",  # NOQA
-    "leprikon/lib/bootstrap/js/bootstrap.js": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/js/bootstrap.js",  # NOQA
+    "leprikon/lib/bootstrap/css/bootstrap-theme.css": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/css/bootstrap-theme.css",  # NOQA
+    "leprikon/lib/bootstrap/css/bootstrap.min.css": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/css/bootstrap.min.css",  # NOQA
+    "leprikon/lib/bootstrap/css/bootstrap-theme.css.map": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/css/bootstrap-theme.css.map",  # NOQA
+    "leprikon/lib/bootstrap/css/bootstrap.min.css.map": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/css/bootstrap.min.css.map",  # NOQA
+    "leprikon/lib/bootstrap/css/bootstrap-theme.min.css": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/css/bootstrap-theme.min.css",  # NOQA
+    "leprikon/lib/bootstrap/css/bootstrap.css": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/css/bootstrap.css",  # NOQA
+    "leprikon/lib/bootstrap/css/bootstrap-theme.min.css.map": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/css/bootstrap-theme.min.css.map",  # NOQA
+    "leprikon/lib/bootstrap/css/bootstrap.css.map": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/css/bootstrap.css.map",  # NOQA
+    "leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.svg": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/fonts/glyphicons-halflings-regular.svg",  # NOQA
+    "leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.ttf": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/fonts/glyphicons-halflings-regular.ttf",  # NOQA
+    "leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.eot": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/fonts/glyphicons-halflings-regular.eot",  # NOQA
+    "leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.woff": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/fonts/glyphicons-halflings-regular.woff",  # NOQA
+    "leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.woff2": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/fonts/glyphicons-halflings-regular.woff2",  # NOQA
+    "leprikon/lib/bootstrap/js/bootstrap.min.js": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/js/bootstrap.min.js",  # NOQA
+    "leprikon/lib/bootstrap/js/npm.js": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/js/npm.js",  # NOQA
+    "leprikon/lib/bootstrap/js/bootstrap.js": "https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/js/bootstrap.js",  # NOQA
     "leprikon/lib/bootstrap-datetimepicker.min.css": (
         "https://cdnjs.cloudflare.com/ajax/libs/bootstrap-datetimepicker/4.17.37/css/bootstrap-datetimepicker.min.css",
         "sha384",
@@ -39,14 +39,14 @@ staticfiles_urls = {
         "2q+7Pk3OSOseTKfNi/t8mZzYRIovdg+nfXYeKmmnivkyD+nxosintmGKX7SWcrOG",
     ),  # NOQA
     "leprikon/lib/ekko-lightbox.min.css": (
-        "https://cdnjs.cloudflare.com/ajax/libs/ekko-lightbox/4.0.1/ekko-lightbox.min.css",
-        "sha384",
-        "EsoR0pjPTZTUy5b8kJf6aTfA7quYluD5mNQ/Lz4hsxU2kXuuc6PlXVfBJCFdTXqD",
+        "https://cdnjs.cloudflare.com/ajax/libs/ekko-lightbox/5.3.0/ekko-lightbox.css",
+        "sha512",
+        "Velp0ebMKjcd9RiCoaHhLXkR1sFoCCWXNp6w4zj1hfMifYB5441C+sKeBl/T/Ka6NjBiRfBBQRaQ\nq65ekYz3UQ==",
     ),  # NOQA
     "leprikon/lib/ekko-lightbox.min.js": (
-        "https://cdnjs.cloudflare.com/ajax/libs/ekko-lightbox/4.0.1/ekko-lightbox.min.js",
-        "sha384",
-        "2aVpK/uKiYlyFXHZ36wvxOPZyWeouEKvbSUlqCrkFhyT80n2aSYtT15Tgdn6g41M",
+        "https://cdnjs.cloudflare.com/ajax/libs/ekko-lightbox/5.3.0/ekko-lightbox.min.js",
+        "sha512",
+        "Y2IiVZeaBwXG1wSV7f13plqlmFOx8MdjuHyYFVoYzhyRr3nH/NMDjTBSswijzADdNzMyWNetbLMf\nOpIPl6Cv9g==",
     ),  # NOQA
     "leprikon/lib/jquery.min.js": (
         "https://cdnjs.cloudflare.com/ajax/libs/jquery/1.12.4/jquery.min.js",
