@@ -5,12 +5,14 @@ from django.contrib import admin
 from django.contrib.auth import get_user_model
 from django.http import Http404
 from django.template.response import TemplateResponse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from . import (  # NOQA
     account,
+    activities,
     agegroup,
     agreements,
+    calendar,
     citizenship,
     courses,
     department,
@@ -29,7 +31,7 @@ from . import (  # NOQA
     roles,
     school,
     schoolyear,
-    subjects,
+    statgroup,
     targetgroup,
     timesheets,
     transaction,
