@@ -1,65 +1,36 @@
 from django import forms
 from django.contrib import admin
 from django.contrib.admin.widgets import AdminRadioSelect, FilteredSelectMultiple
-from django.contrib.auth import get_user_model
-from django.contrib.staticfiles.templatetags.staticfiles import static
-from django.db.models import F
 from django.shortcuts import render
+from django.templatetags.static import static
 from django.urls import reverse
 from django.utils.html import format_html
-from django.utils.translation import ugettext_lazy as _
+from django.utils.safestring import mark_safe
+from django.utils.translation import gettext_lazy as _
 
 from ..forms.courses import CourseDiscountAdminForm, CourseRegistrationAdminForm
-from ..models.courses import Course, CourseDiscount, CourseRegistration, CourseRegistrationHistory, CourseVariant
+from ..models.activities import ActivityModel
+from ..models.courses import Course, CourseDiscount, CourseRegistration
 from ..models.schoolyear import SchoolYear, SchoolYearDivision
-from ..models.subjects import SubjectType
 from ..utils import attributes, currency
+from .activities import ActivityBaseAdmin, ActivityDiscountBaseAdmin, RegistrationBaseAdmin
 from .pdf import PdfExportAdminMixin
-from .subjects import (
-    SubjectAttachmentInlineAdmin,
-    SubjectBaseAdmin,
-    SubjectDiscountBaseAdmin,
-    SubjectRegistrationBaseAdmin,
-    SubjectTimeInlineAdmin,
-    SubjectVariantInlineAdmin,
-)
-
-
-class CourseVariantInlineAdmin(SubjectVariantInlineAdmin):
-    model = CourseVariant
-
-    def get_formset(self, request, obj=None, **kwargs):
-        formset = super().get_formset(request, obj, **kwargs)
-        if "school_year_division" in formset.form.base_fields:
-            # school year division choices
-            school_year_division_choices = formset.form.base_fields["school_year_division"].widget.widget.choices
-            school_year_division_choices.queryset = SchoolYearDivision.objects.filter(
-                school_year=obj.school_year if obj else request.school_year,
-            )
-            formset.form.base_fields["school_year_division"].choices = school_year_division_choices
-        return formset
 
 
 @admin.register(Course)
-class CourseAdmin(SubjectBaseAdmin):
-    subject_type_type = SubjectType.COURSE
+class CourseAdmin(ActivityBaseAdmin):
+    activity_type_model = ActivityModel.COURSE
     registration_model = CourseRegistration
-    inlines = (
-        CourseVariantInlineAdmin,
-        SubjectTimeInlineAdmin,
-        SubjectAttachmentInlineAdmin,
-    )
     list_display = (
         "id",
         "code",
         "name",
-        "subject_type",
+        "activity_type",
         "get_groups_list",
         "get_leaders_list",
         "get_times_list",
         "place",
-        "public",
-        "registration_allowed_icon",
+        "get_registering_link",
         "get_registrations_link",
         "journals_link",
         "icon",
@@ -71,7 +42,7 @@ class CourseAdmin(SubjectBaseAdmin):
         "code",
         "name",
         "department",
-        "subject_type",
+        "activity_type",
         "registration_type",
         "get_groups_list",
         "get_leaders_list",
@@ -80,33 +51,18 @@ class CourseAdmin(SubjectBaseAdmin):
         "get_times_list",
         "place",
         "public",
-        "registration_price",
-        "participant_price",
-        "min_participants_count",
-        "max_participants_count",
         "min_registrations_count",
         "max_registrations_count",
         "get_approved_registrations_count",
         "get_unapproved_registrations_count",
         "note",
     )
-    actions = (
+    actions = ActivityBaseAdmin.actions + (
         "publish",
         "unpublish",
         "copy_to_school_year",
     )
 
-    def get_form(self, request, obj=None, **kwargs):
-        form = super().get_form(request, obj, **kwargs)
-        if "school_year_division" in form.base_fields:
-            # school year division choices
-            school_year_division_choices = form.base_fields["school_year_division"].widget.widget.choices
-            school_year_division_choices.queryset = SchoolYearDivision.objects.filter(
-                school_year=obj.school_year if obj else request.school_year,
-            )
-            form.base_fields["school_year_division"].choices = school_year_division_choices
-        return form
-
     @attributes(short_description=_("Publish selected courses"))
     def publish(self, request, queryset):
         Course.objects.filter(id__in=[reg["id"] for reg in queryset.values("id")]).update(public=True)
@@ -160,45 +116,12 @@ class CourseAdmin(SubjectBaseAdmin):
             ),
         )
 
-    def get_message_recipients(self, request, queryset):
-        return (
-            get_user_model()
-            .objects.filter(
-                leprikon_registrations__subject__in=queryset,
-            )
-            .distinct()
-        )
-
-
-class CourseRegistrationHistoryInlineAdmin(admin.TabularInline):
-    model = CourseRegistrationHistory
-    extra = 0
-    readonly_fields = ("course",)
-
-    def has_add_permission(self, request):
-        return False
-
-    def has_delete_permission(self, request, obj=None):
-        return False
-
 
 @admin.register(CourseRegistration)
-class CourseRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdmin):
+class CourseRegistrationAdmin(PdfExportAdminMixin, RegistrationBaseAdmin):
     form = CourseRegistrationAdminForm
-    subject_type_type = SubjectType.COURSE
-    actions = ("add_discounts",)
-    inlines = SubjectRegistrationBaseAdmin.inlines + (CourseRegistrationHistoryInlineAdmin,)
-
-    def get_form(self, request, obj=None, **kwargs):
-        form = super().get_form(request, obj, **kwargs)
-        if "school_year_division" in form.base_fields:
-            # school year division choices
-            school_year_division_choices = form.base_fields["school_year_division"].widget.widget.choices
-            school_year_division_choices.queryset = SchoolYearDivision.objects.filter(
-                school_year=obj.subject.school_year if obj else request.school_year,
-            )
-            form.base_fields["school_year_division"].choices = school_year_division_choices
-        return form
+    activity_type_model = ActivityModel.COURSE
+    actions = RegistrationBaseAdmin.actions + PdfExportAdminMixin.actions + ("add_discounts",)
 
     def get_queryset(self, request):
         return (
@@ -226,7 +149,7 @@ class CourseRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdmin)
         school_year_divisions = {
             school_year_division.id: school_year_division
             for school_year_division in SchoolYearDivision.objects.filter(
-                courses__registrations__in=queryset,
+                variants__activity__registrations__in=queryset,
             ).distinct()
         }
 
@@ -240,6 +163,7 @@ class CourseRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdmin)
                         school_year_division=school_year_division.name,
                     ),
                     queryset=school_year_division.periods.all(),
+                    required=False,
                     widget=FilteredSelectMultiple(
                         verbose_name=label.format(
                             school_year_division=school_year_division.name,
@@ -273,11 +197,9 @@ class CourseRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdmin)
                         ),
                         explanation=form.cleaned_data["explanation"],
                     )
-                    for registration in queryset.annotate(
-                        school_year_division_id=F("subject__course__school_year_division_id")
-                    )
+                    for registration in queryset.all()
                     for registration_period in registration.course_registration_periods.filter(
-                        period__in=form.cleaned_data[f"periods_{registration.school_year_division_id}"]
+                        period__in=form.cleaned_data[f"periods_{registration.activity_variant.school_year_division_id}"]
                     )
                 )
                 self.message_user(request, _("The discounts have been created for selected registrations."))
@@ -308,7 +230,7 @@ class CourseRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdmin)
             ),
         )
 
-    @attributes(allow_tags=True, short_description=_("discounts"))
+    @attributes(short_description=_("discounts"))
     def discounts(self, obj: CourseRegistration):
         html = []
         for status in obj.period_payment_statuses:
@@ -328,9 +250,9 @@ class CourseRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdmin)
                     icon=static("admin/img/icon-addlink.svg"),
                 )
             )
-        return "<br/>".join(html)
+        return mark_safe("<br/>".join(html))
 
-    @attributes(allow_tags=True, short_description=_("total price"))
+    @attributes(short_description=_("total price"))
     def total_price(self, obj: CourseRegistration):
         html = []
         for status in obj.period_payment_statuses:
@@ -341,9 +263,9 @@ class CourseRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdmin)
                     amount=currency(status.status.receivable),
                 )
             )
-        return "<br/>".join(html)
+        return mark_safe("<br/>".join(html))
 
-    @attributes(allow_tags=True, short_description=_("received payments"))
+    @attributes(short_description=_("received payments"), admin_order_field="cached_balance")
     def received_payments(self, obj: CourseRegistration):
         html = []
         for period in obj.period_payment_statuses:
@@ -352,24 +274,46 @@ class CourseRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdmin)
                     '{period}: <a style="color: {color}" href="{href}" title="{title}">' "<b>{amount}</b></a>",
                     period=period.registration_period.period.name,
                     color=period.status.color,
-                    href=reverse("admin:leprikon_subjectreceivedpayment_changelist") + f"?target_registration={obj.id}",
+                    href=reverse("admin:leprikon_receivedpayment_changelist") + f"?target_registration={obj.id}",
                     title=period.status.title,
                     amount=currency(period.status.received),
                 )
                 + format_html(
                     '<a class="popup-link" href="{href}" style="background-position: 0 0" title="{title}">'
                     '<img src="{icon}" alt="+"/></a>',
-                    href=reverse("admin:leprikon_subjectreceivedpayment_add") + f"?target_registration={obj.id}",
+                    href=reverse("admin:leprikon_receivedpayment_add") + f"?target_registration={obj.id}",
                     title=_("add payment"),
                     icon=static("admin/img/icon-addlink.svg"),
                 )
             )
-        return "<br/>".join(html)
+        return mark_safe("<br/>".join(html))
+
+    @attributes(short_description=_("discounts"))
+    def discounts_export(self, obj: CourseRegistration):
+        return "\n".join(
+            f"{status.registration_period.period.name}: {currency(status.status.discount)}"
+            for status in obj.period_payment_statuses
+        )
+
+    @attributes(short_description=_("total price"))
+    def total_price_export(self, obj: CourseRegistration):
+        return "\n".join(
+            f"{status.registration_period.period.name}: {currency(status.status.receivable)}"
+            for status in obj.period_payment_statuses
+        )
+
+    @attributes(short_description=_("received payments"))
+    def received_payments_export(self, obj: CourseRegistration):
+        return "\n".join(
+            f"{status.registration_period.period.name}: {currency(status.status.received)}"
+            for status in obj.period_payment_statuses
+        )
 
 
 @admin.register(CourseDiscount)
-class CourseDiscountAdmin(PdfExportAdminMixin, SubjectDiscountBaseAdmin):
+class CourseDiscountAdmin(ActivityDiscountBaseAdmin):
+    actions = ActivityDiscountBaseAdmin.actions
     form = CourseDiscountAdminForm
-    list_display = ("accounted", "registration", "subject", "period", "amount_html", "explanation")
-    list_export = ("accounted", "registration", "subject", "period", "amount", "explanation")
+    list_display = ("accounted", "registration", "activity", "period", "amount_html", "explanation")
+    list_export = ("accounted", "registration", "activity", "period", "amount", "explanation")
     closed_fields = ("accounted", "registration", "period", "amount")
