@@ -1,37 +1,41 @@
 from django import forms
 from django.contrib import admin
 from django.contrib.admin.widgets import AdminRadioSelect
-from django.contrib.auth import get_user_model
-from django.contrib.staticfiles.templatetags.staticfiles import static
 from django.shortcuts import render
+from django.templatetags.static import static
 from django.urls import reverse
 from django.utils.html import format_html
-from django.utils.translation import ugettext_lazy as _
+from django.utils.safestring import mark_safe
+from django.utils.translation import gettext_lazy as _
 
+from ..models.activities import ActivityModel
 from ..models.events import Event, EventDiscount, EventRegistration
 from ..models.schoolyear import SchoolYear
-from ..models.subjects import SubjectType
 from ..utils import attributes, currency
+from .activities import ActivityBaseAdmin, ActivityDiscountBaseAdmin, RegistrationBaseAdmin
 from .pdf import PdfExportAdminMixin
-from .subjects import SubjectBaseAdmin, SubjectDiscountBaseAdmin, SubjectRegistrationBaseAdmin
 
 
 @admin.register(Event)
-class EventAdmin(SubjectBaseAdmin):
-    subject_type_type = SubjectType.EVENT
+class EventAdmin(ActivityBaseAdmin):
+    activity_type_model = ActivityModel.EVENT
     registration_model = EventRegistration
+    actions = ActivityBaseAdmin.actions + (
+        "publish",
+        "unpublish",
+        "copy_to_school_year",
+    )
     list_display = (
         "id",
         "code",
         "name",
-        "subject_type",
+        "activity_type",
         "get_groups_list",
         "get_leaders_list",
         "get_times_list",
         "event_date",
         "place",
-        "public",
-        "registration_allowed_icon",
+        "get_registering_link",
         "get_registrations_link",
         "journals_link",
         "icon",
@@ -43,7 +47,7 @@ class EventAdmin(SubjectBaseAdmin):
         "code",
         "name",
         "department",
-        "subject_type",
+        "activity_type",
         "registration_type",
         "get_groups_list",
         "get_leaders_list",
@@ -56,9 +60,6 @@ class EventAdmin(SubjectBaseAdmin):
         "end_time",
         "place",
         "public",
-        "price",
-        "min_participants_count",
-        "max_participants_count",
         "min_registrations_count",
         "max_registrations_count",
         "get_approved_registrations_count",
@@ -66,11 +67,6 @@ class EventAdmin(SubjectBaseAdmin):
         "note",
     )
     date_hierarchy = "start_date"
-    actions = (
-        "publish",
-        "unpublish",
-        "copy_to_school_year",
-    )
 
     @attributes(short_description=_("Publish selected events"))
     def publish(self, request, queryset):
@@ -125,20 +121,11 @@ class EventAdmin(SubjectBaseAdmin):
             ),
         )
 
-    def get_message_recipients(self, request, queryset):
-        return (
-            get_user_model()
-            .objects.filter(
-                leprikon_registrations__subject__in=queryset,
-            )
-            .distinct()
-        )
-
 
 @admin.register(EventRegistration)
-class EventRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdmin):
-    subject_type_type = SubjectType.EVENT
-    actions = ("add_discounts",)
+class EventRegistrationAdmin(PdfExportAdminMixin, RegistrationBaseAdmin):
+    activity_type_model = ActivityModel.EVENT
+    actions = RegistrationBaseAdmin.actions + PdfExportAdminMixin.actions + ("add_discounts",)
 
     @attributes(short_description=_("Add discounts to selected registrations"))
     def add_discounts(self, request, queryset):
@@ -199,21 +186,36 @@ class EventRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdmin):
             ),
         )
 
-    @attributes(allow_tags=True, short_description=_("discounts"))
+    @attributes(short_description=_("discounts"))
     def discounts(self, obj: EventRegistration):
-        return format_html(
-            '<a href="{href_list}"><b>{amount}</b></a>'
-            ' &nbsp; <a class="popup-link" href="{href_add}" style="background-position: 0 0" title="{title_add}">'
-            '<img src="{icon_add}" alt="+"/></a>',
-            href_list=reverse("admin:leprikon_eventdiscount_changelist") + f"?registration={obj.id}",
-            amount=currency(obj.payment_status.discount),
-            href_add=reverse("admin:leprikon_eventdiscount_add") + f"?registration={obj.id}",
-            icon_add=static("admin/img/icon-addlink.svg"),
-            title_add=_("add discount"),
+        return mark_safe(
+            format_html(
+                '<a href="{href_list}"><b>{amount}</b></a>'
+                ' &nbsp; <a class="popup-link" href="{href_add}" style="background-position: 0 0" title="{title_add}">'
+                '<img src="{icon_add}" alt="+"/></a>',
+                href_list=reverse("admin:leprikon_eventdiscount_changelist") + f"?registration={obj.id}",
+                amount=currency(obj.payment_status.discount),
+                href_add=reverse("admin:leprikon_eventdiscount_add") + f"?registration={obj.id}",
+                icon_add=static("admin/img/icon-addlink.svg"),
+                title_add=_("add discount"),
+            )
         )
 
+    @attributes(short_description=_("discounts"))
+    def discounts_export(self, obj: EventRegistration):
+        return currency(obj.payment_status.discount)
+
+    @attributes(short_description=_("total price"))
+    def total_price_export(self, obj: EventRegistration):
+        return currency(obj.payment_status.receivable)
+
+    @attributes(short_description=_("received payments"))
+    def received_payments_export(self, obj: EventRegistration):
+        return currency(obj.payment_status.received)
+
 
 @admin.register(EventDiscount)
-class EventDiscountAdmin(PdfExportAdminMixin, SubjectDiscountBaseAdmin):
-    list_display = ("accounted", "registration", "subject", "amount_html", "explanation")
-    list_export = ("accounted", "registration", "subject", "amount", "explanation")
+class EventDiscountAdmin(ActivityDiscountBaseAdmin):
+    actions = ActivityDiscountBaseAdmin.actions
+    list_display = ("accounted", "registration", "activity", "amount_html", "explanation")
+    list_export = ("accounted", "registration", "activity", "amount", "explanation")
