@@ -1,37 +1,35 @@
 from django import forms
 from django.contrib import admin
 from django.contrib.admin.widgets import AdminRadioSelect
-from django.contrib.auth import get_user_model
-from django.contrib.staticfiles.templatetags.staticfiles import static
 from django.shortcuts import render
+from django.templatetags.static import static
 from django.urls import reverse
 from django.utils.html import format_html
-from django.utils.translation import ugettext_lazy as _
+from django.utils.safestring import mark_safe
+from django.utils.translation import gettext_lazy as _
 
+from ..models.activities import ActivityModel
 from ..models.orderables import Orderable, OrderableDiscount, OrderableRegistration
 from ..models.schoolyear import SchoolYear
-from ..models.subjects import SubjectType
 from ..utils import attributes, currency
+from .activities import ActivityBaseAdmin, ActivityDiscountBaseAdmin, RegistrationBaseAdmin
 from .pdf import PdfExportAdminMixin
-from .subjects import SubjectBaseAdmin, SubjectDiscountBaseAdmin, SubjectRegistrationBaseAdmin
 
 
 @admin.register(Orderable)
-class OrderableAdmin(SubjectBaseAdmin):
-    subject_type_type = SubjectType.ORDERABLE
+class OrderableAdmin(ActivityBaseAdmin):
+    activity_type_model = ActivityModel.ORDERABLE
     registration_model = OrderableRegistration
     list_display = (
         "id",
         "code",
         "name",
-        "subject_type",
+        "activity_type",
         "get_groups_list",
         "get_leaders_list",
         "get_times_list",
-        "duration",
         "place",
-        "public",
-        "registration_allowed_icon",
+        "get_registering_link",
         "get_registrations_link",
         "journals_link",
         "icon",
@@ -43,7 +41,7 @@ class OrderableAdmin(SubjectBaseAdmin):
         "code",
         "name",
         "department",
-        "subject_type",
+        "activity_type",
         "registration_type",
         "get_groups_list",
         "get_leaders_list",
@@ -52,16 +50,13 @@ class OrderableAdmin(SubjectBaseAdmin):
         "get_times_list",
         "place",
         "public",
-        "price",
-        "min_participants_count",
-        "max_participants_count",
         "min_registrations_count",
         "max_registrations_count",
         "get_approved_registrations_count",
         "get_unapproved_registrations_count",
         "note",
     )
-    actions = (
+    actions = ActivityBaseAdmin.actions + (
         "publish",
         "unpublish",
         "copy_to_school_year",
@@ -123,23 +118,12 @@ class OrderableAdmin(SubjectBaseAdmin):
             ),
         )
 
-    def get_message_recipients(self, request, queryset):
-        return (
-            get_user_model()
-            .objects.filter(
-                leprikon_registrations__subject__in=queryset,
-            )
-            .distinct()
-        )
-
 
 @admin.register(OrderableRegistration)
-class OrderableRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdmin):
-    subject_type_type = SubjectType.ORDERABLE
-    actions = ("add_discounts",)
-    list_display = (
-        SubjectRegistrationBaseAdmin.list_display[:3] + ("event_date",) + SubjectRegistrationBaseAdmin.list_display[3:]
-    )
+class OrderableRegistrationAdmin(PdfExportAdminMixin, RegistrationBaseAdmin):
+    activity_type_model = ActivityModel.ORDERABLE
+    actions = RegistrationBaseAdmin.actions + PdfExportAdminMixin.actions + ("add_discounts",)
+    list_display = RegistrationBaseAdmin.list_display[:3] + ("event_date",) + RegistrationBaseAdmin.list_display[3:]
 
     @attributes(short_description=_("Add discounts to selected registrations"))
     def add_discounts(self, request, queryset):
@@ -200,37 +184,54 @@ class OrderableRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdm
             ),
         )
 
-    @attributes(allow_tags=True, short_description=_("discounts"))
+    @attributes(short_description=_("discounts"))
     def discounts(self, obj: OrderableRegistration):
-        return format_html(
-            '<a href="{href_list}"><b>{amount}</b></a>'
-            ' &nbsp; <a class="popup-link" href="{href_add}" style="background-position: 0 0" title="{title_add}">'
-            '<img src="{icon_add}" alt="+"/></a>',
-            href_list=reverse("admin:leprikon_orderablediscount_changelist") + f"?registration={obj.id}",
-            amount=currency(obj.payment_status.discount),
-            href_add=reverse("admin:leprikon_orderablediscount_add") + f"?registration={obj.id}",
-            icon_add=static("admin/img/icon-addlink.svg"),
-            title_add=_("add discount"),
+        return mark_safe(
+            format_html(
+                '<a href="{href_list}"><b>{amount}</b></a>'
+                ' &nbsp; <a class="popup-link" href="{href_add}" style="background-position: 0 0" title="{title_add}">'
+                '<img src="{icon_add}" alt="+"/></a>',
+                href_list=reverse("admin:leprikon_orderablediscount_changelist") + f"?registration={obj.id}",
+                amount=currency(obj.payment_status.discount),
+                href_add=reverse("admin:leprikon_orderablediscount_add") + f"?registration={obj.id}",
+                icon_add=static("admin/img/icon-addlink.svg"),
+                title_add=_("add discount"),
+            )
         )
 
-    @attributes(allow_tags=True, short_description=_("received payments"))
+    @attributes(short_description=_("received payments"))
     def received_payments(self, obj: OrderableRegistration):
-        return format_html(
-            '<a style="color: {color}" href="{href_list}" title="{title}"><b>{amount}</b></a>'
-            ' &nbsp; <a class="popup-link" href="{href_add}" style="background-position: 0 0" title="{title_add}">'
-            '<img src="{icon_add}" alt="+"/></a>',
-            color=obj.payment_status.color,
-            href_list=reverse("admin:leprikon_subjectreceivedpayment_changelist")
-            + "?target_registration={}".format(obj.id),
-            title=obj.payment_status.title,
-            amount=currency(obj.payment_status.received),
-            href_add=reverse("admin:leprikon_subjectreceivedpayment_add") + "?target_registration={}".format(obj.id),
-            icon_add=static("admin/img/icon-addlink.svg"),
-            title_add=_("add payment"),
+        return mark_safe(
+            format_html(
+                '<a style="color: {color}" href="{href_list}" title="{title}"><b>{amount}</b></a>'
+                ' &nbsp; <a class="popup-link" href="{href_add}" style="background-position: 0 0" title="{title_add}">'
+                '<img src="{icon_add}" alt="+"/></a>',
+                color=obj.payment_status.color,
+                href_list=reverse("admin:leprikon_receivedpayment_changelist")
+                + "?target_registration={}".format(obj.id),
+                title=obj.payment_status.title,
+                amount=currency(obj.payment_status.received),
+                href_add=reverse("admin:leprikon_receivedpayment_add") + "?target_registration={}".format(obj.id),
+                icon_add=static("admin/img/icon-addlink.svg"),
+                title_add=_("add payment"),
+            )
         )
 
+    @attributes(short_description=_("discounts"))
+    def discounts_export(self, obj: OrderableRegistration):
+        return currency(obj.payment_status.discount)
+
+    @attributes(short_description=_("total price"))
+    def total_price_export(self, obj: OrderableRegistration):
+        return currency(obj.payment_status.receivable)
+
+    @attributes(short_description=_("received payments"))
+    def received_payments_export(self, obj: OrderableRegistration):
+        return currency(obj.payment_status.received)
+
 
 @admin.register(OrderableDiscount)
-class OrderableDiscountAdmin(PdfExportAdminMixin, SubjectDiscountBaseAdmin):
-    list_display = ("accounted", "registration", "subject", "amount_html", "explanation")
-    list_export = ("accounted", "registration", "subject", "amount", "explanation")
+class OrderableDiscountAdmin(ActivityDiscountBaseAdmin):
+    actions = ActivityDiscountBaseAdmin.actions
+    list_display = ("accounted", "registration", "activity", "amount_html", "explanation")
+    list_export = ("accounted", "registration", "activity", "amount", "explanation")
