@@ -1,5 +1,5 @@
 from cms.plugin_pool import plugin_pool
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from ..models.orderables import FilteredOrderableListPlugin, OrderableListPlugin, OrderablePlugin
 from .base import LeprikonPluginBase
