@@ -1,13 +1,15 @@
 from datetime import date
+from typing import List
 
 from django import forms
 from django.core.exceptions import ValidationError
 from django.forms.models import inlineformset_factory
-from django.utils.translation import ugettext_lazy as _, ungettext_lazy as ungettext
+from django.utils.translation import gettext_lazy as _, ngettext_lazy as ngettext
 
+from ..models.activities import ActivityModel, RegistrationParticipant
 from ..models.journals import Journal, JournalEntry, JournalLeaderEntry, JournalTime
 from ..models.roles import Leader
-from ..models.subjects import SubjectRegistrationParticipant
+from ..models.schoolyear import SchoolYearDivision, SchoolYearPeriod
 from ..models.timesheets import Timesheet, TimesheetPeriod
 from ..utils import comma_separated, first_upper
 from .fields import ReadonlyField
@@ -15,75 +17,136 @@ from .form import FormMixin
 from .widgets import CheckboxSelectMultipleBootstrap
 
 
+def get_participant_choices(participants_qs):
+    participants: List[RegistrationParticipant] = list(participants_qs.select_related("registration"))
+    groups = (
+        (
+            _("Approved participants"),
+            tuple(
+                (participant.id, participant)
+                for participant in participants
+                if participant.registration.approved and not participant.registration.canceled
+            ),
+        ),
+        (
+            _("Canceled participants"),
+            tuple(
+                (participant.id, participant)
+                for participant in participants
+                if participant.registration.approved and participant.registration.canceled
+            ),
+        ),
+        (
+            _("Not approved participants"),
+            tuple(
+                (participant.id, participant) for participant in participants if not participant.registration.approved
+            ),
+        ),
+    )
+    return tuple(group for group in groups if group[1])
+
+
 class JournalAdminForm(forms.ModelForm):
     class Meta:
         model = Journal
-        exclude = []
+        exclude = ["activity", "school_year_division"]
 
     def __init__(self, data=None, *args, **kwargs):
         super().__init__(data, *args, **kwargs)
 
         # limit choices of leaders
         leaders_choices = self.fields["leaders"].widget.choices
-        leaders_choices.queryset = leaders_choices.queryset.filter(subjects=self.subject)
+        leaders_choices.queryset = leaders_choices.queryset.filter(activities=self.activity)
 
-        participant_ids = set(
-            SubjectRegistrationParticipant.objects.filter(
-                registration__approved__isnull=False,
-                registration__subject_id=self.subject.id,
-            ).values_list("id", flat=True)
-        )
-        if self.instance.id:
-            participant_ids |= set(self.instance.participants.values_list("id", flat=True))
-            participant_ids |= set(
-                SubjectRegistrationParticipant.objects.filter(
-                    journal_entries__journal=self.instance,
-                ).values_list("id", flat=True),
+        # limit choices of participants
+        participants_qs = RegistrationParticipant.objects.filter(registration__activity=self.activity)
+
+        if self.activity.activity_type.model == ActivityModel.COURSE:
+            participants_qs = participants_qs.filter(
+                registration__activity_variant__school_year_division=self.instance.school_year_division
             )
-        self.fields["participants"].widget.choices.queryset = SubjectRegistrationParticipant.objects.filter(
+
+        participant_ids = set(participants_qs.values_list("id", flat=True))
+        participant_ids |= set(self.instance.participants.values_list("id", flat=True))
+        participant_ids |= set(
+            RegistrationParticipant.objects.filter(
+                journal_entries__journal=self.instance,
+            ).values_list("id", flat=True),
+        )
+        self.fields["participants"].widget.choices.queryset = RegistrationParticipant.objects.filter(
             id__in=participant_ids
         )
 
 
-class JournalForm(FormMixin, forms.ModelForm):
+class JournalCreateForm(FormMixin, forms.ModelForm):
+    class Meta:
+        model = Journal
+        fields = ["name", "school_year_division", "leaders"]
+        widgets = {
+            "leaders": CheckboxSelectMultipleBootstrap(),
+        }
+
+    def __init__(self, *args, **kwargs):
+        self.activity = kwargs.pop("activity", None) or kwargs["instance"].activity
+        super().__init__(*args, **kwargs)
+        self.instance.activity = self.activity
+        self.readonly_fields = [
+            ReadonlyField(label=first_upper(self.activity.activity_type.name), value=self.activity),
+        ]
+
+        school_year_divisions = SchoolYearDivision.objects.filter(variants__activity=self.activity).distinct()
+        if school_year_divisions.exists():
+            self.fields["school_year_division"].widget.choices.queryset = school_year_divisions
+        else:
+            del self.fields["school_year_division"]
+
+        self.fields["leaders"].widget.choices = tuple((leader.id, leader) for leader in self.activity.all_leaders)
+
+
+class JournalUpdateForm(FormMixin, forms.ModelForm):
     JournalTimeFormset = inlineformset_factory(
-        Journal, JournalTime, fields=["day_of_week", "start", "end"], can_delete=True, extra=1
+        Journal, JournalTime, fields=["days_of_week", "start_time", "end_time"], can_delete=True, extra=1
     )
 
     class Meta:
         model = Journal
-        exclude = ["subject"]
+        exclude = ["activity", "school_year_division"]
         widgets = {
             "leaders": CheckboxSelectMultipleBootstrap(),
             "participants": CheckboxSelectMultipleBootstrap(),
         }
 
     def __init__(self, *args, **kwargs):
-        self.subject = kwargs.pop("subject", None) or kwargs["instance"].subject
+        self.activity = kwargs.pop("activity", None) or kwargs["instance"].activity
         super().__init__(*args, **kwargs)
-        self.instance.subject = self.subject
+        self.instance.activity = self.activity
         self.readonly_fields = [
-            ReadonlyField(label=first_upper(self.subject.subject_type.name), value=self.subject),
+            ReadonlyField(label=first_upper(self.activity.activity_type.name), value=self.activity),
         ]
-        self.fields["leaders"].widget.choices = tuple((leader.id, leader) for leader in self.subject.all_leaders)
 
-        participant_ids = set(
-            SubjectRegistrationParticipant.objects.filter(
-                registration__approved__isnull=False,
-                registration__subject_id=self.subject.id,
-            ).values_list("id", flat=True)
-        )
-        if self.instance.id:
-            participant_ids |= set(self.instance.participants.values_list("id", flat=True))
-            participant_ids |= set(
-                SubjectRegistrationParticipant.objects.filter(
-                    journal_entries__journal=self.instance,
-                ).values_list("id", flat=True),
+        participants_qs = RegistrationParticipant.objects.filter(registration__activity_id=self.activity.id)
+
+        if self.instance.school_year_division:
+            self.readonly_fields.append(
+                ReadonlyField(label=first_upper(_("school year division")), value=self.instance.school_year_division),
             )
-        self.fields["participants"].widget.choices = tuple(
-            (participant.id, participant)
-            for participant in SubjectRegistrationParticipant.objects.filter(id__in=participant_ids)
+            participants_qs = participants_qs.filter(
+                registration__activity_variant__school_year_division=self.instance.school_year_division
+            )
+
+        participant_ids = set(participants_qs.values_list("id", flat=True))
+        participant_ids |= set(self.instance.participants.values_list("id", flat=True))
+        participant_ids |= set(
+            RegistrationParticipant.objects.filter(
+                journal_entries__journal=self.instance,
+            ).values_list("id", flat=True),
         )
+        self.fields["participants"].widget.choices = get_participant_choices(
+            RegistrationParticipant.objects.filter(id__in=participant_ids)
+        )
+
+        self.fields["leaders"].widget.choices = tuple((leader.id, leader) for leader in self.activity.all_leaders)
+
         self.inline_formsets = [self.JournalTimeFormset(data=kwargs.get("data"), instance=kwargs.get("instance"))]
 
     def is_valid(self) -> bool:
@@ -154,10 +217,10 @@ class JournalLeaderEntryForm(FormMixin, JournalLeaderEntryAdminForm):
 class JournalEntryAdminForm(forms.ModelForm):
     class Meta:
         model = JournalEntry
-        fields = ["date", "start", "end", "agenda", "participants", "participants_instructed"]
+        fields = ["date", "start", "end", "period", "agenda", "participants", "participants_instructed"]
 
     def __init__(self, *args, **kwargs):
-        self.journal = kwargs.pop("journal", None) or kwargs["instance"].journal
+        self.journal: Journal = kwargs.pop("journal", None) or kwargs["instance"].journal
         super().__init__(*args, **kwargs)
         self.instance.journal = self.journal
 
@@ -187,10 +250,20 @@ class JournalEntryAdminForm(forms.ModelForm):
                 d = self.fields["date"].clean(kwargs["data"]["date"])
             except (KeyError, TypeError, ValidationError):
                 d = self.initial["date"]
-        self.fields["participants"].widget.choices.queryset = self.instance.journal.get_valid_participants(d)
+        if self.journal.school_year_division_id:
+            self.fields["period"].widget.choices.queryset = SchoolYearPeriod.objects.filter(
+                school_year_division_id=self.journal.school_year_division_id
+            )
+            self.fields["period"].required = True
+        else:
+            del self.fields["period"]
+
+        participants_choices = get_participant_choices(self.instance.journal.get_valid_participants(d))
+
+        self.fields["participants"].widget.choices = participants_choices
         self.fields["participants"].help_text = None
 
-        self.fields["participants_instructed"].widget.choices.queryset = self.instance.journal.get_valid_participants(d)
+        self.fields["participants_instructed"].widget.choices = participants_choices
         self.fields["participants_instructed"].help_text = None
 
     def clean(self):
@@ -361,7 +434,7 @@ class JournalEntryForm(FormMixin, JournalEntryAdminForm):
                     self.deleted_entries.append(entry)
 
             if leaders_with_submitted_timesheets["leaders"]:
-                errors["leaders"] = ungettext(
+                errors["leaders"] = ngettext(
                     "Leader {leaders} has already submitted timesheet for {period}.",
                     "Leaders {leaders} have already submitted timesheet for {period}.",
                     len(leaders_with_submitted_timesheets["leaders"]),
@@ -370,7 +443,7 @@ class JournalEntryForm(FormMixin, JournalEntryAdminForm):
                     period=period.name,
                 )
             if leaders_with_submitted_timesheets["alternates"]:
-                errors["alternates"] = ungettext(
+                errors["alternates"] = ngettext(
                     "Alternate {leaders} has already submitted timesheet for {period}.",
                     "Alternates {leaders} have already submitted timesheet for {period}.",
                     len(leaders_with_submitted_timesheets["alternates"]),
