@@ -2,7 +2,7 @@ from django import forms
 from django.contrib.admin import widgets
 from django.contrib.auth import get_user_model
 from django.db.models import Q
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from ..models.messages import Message, MessageRecipient
 from .form import FormMixin
