@@ -9,7 +9,7 @@ from django.contrib.auth.forms import (
     UserCreationForm as _UserCreationForm,
 )
 from django.core.exceptions import ValidationError
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from verified_email_field.auth import EmailAuthenticationForm as _EmailAuthenticationForm
 from verified_email_field.forms import VerifiedEmailField
 
@@ -35,7 +35,6 @@ class UserFormMixin(FormMixin):
 
 
 class UserAdminCreateForm(UserFormMixin, forms.ModelForm):
-
     # create user with random password
     # users without password may not reset the password themselves
     def save(self, commit=True):
