@@ -1,5 +1,6 @@
 from . import (  # noqa
     account,
+    activities,
     agegroup,
     agreements,
     citizenship,
@@ -22,7 +23,7 @@ from . import (  # noqa
     school,
     schoolyear,
     startend,
-    subjects,
+    statgroup,
     targetgroup,
     timesheets,
     transaction,
