@@ -1,7 +1,8 @@
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from ..utils import first_upper
+from .statgroup import StatGroup
 
 
 class AgeGroup(models.Model):
@@ -10,6 +11,9 @@ class AgeGroup(models.Model):
     max_age = models.PositiveSmallIntegerField(_("maximal age"), blank=True, null=True)
     order = models.IntegerField(_("order"), blank=True, default=0)
     require_school = models.BooleanField(_("require school"), default=True)
+    stat_group = models.ForeignKey(
+        StatGroup, on_delete=models.PROTECT, related_name="+", verbose_name=_("group for statistics")
+    )
 
     class Meta:
         app_label = "leprikon"
