@@ -1,5 +1,5 @@
 from django.utils.functional import cached_property
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from ..utils import currency
 from .printsetup import PrintSetup
