@@ -3,7 +3,7 @@ from time import time
 from django.contrib.sites.models import Site
 from django.db import models
 from django.utils.functional import cached_property
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django_pays.models import Gateway
 from djangocms_text_ckeditor.fields import HTMLField
 
