@@ -1,9 +1,10 @@
 from datetime import date
 
 from cms.models import CMSPlugin
+from django.core.validators import MaxValueValidator, MinValueValidator
 from django.db import models
 from django.utils.functional import cached_property
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from ..utils import comma_separated
 from .startend import StartEndMixin
@@ -27,7 +28,15 @@ class SchoolYearManager(models.Manager):
 
 
 class SchoolYear(models.Model):
-    year = models.IntegerField(_("year"), unique=True, help_text=_("Only the first of the two years."))
+    year = models.IntegerField(
+        _("year"),
+        unique=True,
+        validators=[
+            MinValueValidator(2000),
+            MaxValueValidator(3000),
+        ],
+        help_text=_("Only the first of the two years."),
+    )
     active = models.BooleanField(_("active"), default=False)
 
     objects = SchoolYearManager()
@@ -112,10 +121,12 @@ class SchoolYearPeriod(StartEndMixin, models.Model):
     price_units_count = models.DecimalField(_("number of price units"), default=1, decimal_places=2, max_digits=10)
     due_from = models.DateField(_("due from"))
     due_date = models.DateField(_("due date"))
+    min_due_date_days = models.PositiveIntegerField(_("minimal number of days to due date"), default=14)
+    order = models.IntegerField(_("order"), blank=True, default=0)
 
     class Meta:
         app_label = "leprikon"
-        ordering = ("start",)
+        ordering = ("order",)
         verbose_name = _("school year period")
         verbose_name_plural = _("school year periods")
 
