@@ -6,7 +6,7 @@ from django.db import models
 from django.urls import reverse_lazy as reverse
 from django.utils.dateformat import DateFormat
 from django.utils.functional import cached_property
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from djangocms_text_ckeditor.fields import HTMLField
 
 from ..utils import attributes
@@ -76,7 +76,7 @@ class Timesheet(models.Model):
 
     class Meta:
         app_label = "leprikon"
-        ordering = ("-period__start",)
+        ordering = ("-period__start", "leader")
         unique_together = (("period", "leader"),)
         verbose_name = _("timesheet")
         verbose_name_plural = _("timesheets")
