@@ -4,10 +4,10 @@ from haystack import indexes
 
 
 class BaseIndex(indexes.SearchIndex, indexes.Indexable):
-    text = indexes.CharField(document=True, use_template=True, template_name='leprikon/search.txt')
-    title = indexes.CharField(stored=True, indexed=False, model_attr='name')
+    text = indexes.CharField(document=True, use_template=True, template_name="leprikon/search.txt")
+    title = indexes.CharField(stored=True, indexed=False, model_attr="name")
     url = indexes.CharField(stored=True, indexed=False)
-    school_year = indexes.IntegerField(stored=True, indexed=True, model_attr='school_year_id')
+    school_year = indexes.IntegerField(stored=True, indexed=True, model_attr="school_year_id")
 
     def prepare(self, obj):
         with override(settings.LANGUAGE_CODE):
