@@ -1,10 +1,11 @@
 from django.http import Http404
 from django.shortcuts import get_object_or_404
 from django.urls.base import reverse_lazy as reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
-from ..forms.journals import JournalEntryForm, JournalForm, JournalLeaderEntryForm
-from ..models.journals import Journal, JournalEntry, JournalLeaderEntry, Subject
+from ..forms.journals import JournalCreateForm, JournalEntryForm, JournalLeaderEntryForm, JournalUpdateForm
+from ..models.journals import Activity, Journal, JournalEntry, JournalLeaderEntry
+from ..utils import reverse_with_back
 from .generic import CreateView, DeleteView, DetailView, TemplateView, UpdateView
 
 
@@ -35,30 +36,35 @@ class JournalView(JournalQuerySetMixin, DetailView):
 
 class JournalCreateView(CreateView):
     model = Journal
-    form_class = JournalForm
+    form_class = JournalCreateForm
     template_name = "leprikon/journal_form.html"
     title = _("New journal")
 
-    def dispatch(self, request, subject):
-        kwargs = {"id": subject}
+    def dispatch(self, request, activity):
+        kwargs = {"id": activity}
         if not self.request.user.is_staff:
             kwargs["leaders"] = self.request.leader
-        self.subject = get_object_or_404(Subject, **kwargs)
-        self.success_url = reverse("leprikon:subject_journals", args=(self.subject.subject_type.slug, self.subject.id))
+        self.activity = get_object_or_404(Activity, **kwargs)
         return super().dispatch(request)
 
     def get_form_kwargs(self):
         kwargs = super().get_form_kwargs()
-        kwargs["subject"] = self.subject
+        kwargs["activity"] = self.activity
+        kwargs["initial"] = dict(leaders=[self.request.leader])
         return kwargs
 
     def get_message(self):
         return _("New journal {} has been created.").format(self.object)
 
+    def get_success_url(self):
+        if self.request.user.is_staff or self.request.leader in self.object.all_leaders:
+            return reverse_with_back(self.request, "leprikon:journal_update", args=(self.object.id,))
+        return self.get_back_url()
+
 
 class JournalUpdateView(JournalQuerySetMixin, UpdateView):
     model = Journal
-    form_class = JournalForm
+    form_class = JournalUpdateForm
     success_url = reverse("leprikon:summary")
     template_name = "leprikon/journal_form.html"
     title = _("Change journal")
@@ -72,7 +78,7 @@ class JournalDeleteView(DeleteView):
     def get_queryset(self):
         qs = super().get_queryset()
         if not self.request.user.is_staff:
-            qs = qs.filter(subject__leaders=self.request.leader)
+            qs = qs.filter(activity__leaders=self.request.leader)
         return qs
 
     def get_object(self):
