@@ -1,6 +1,6 @@
 from django.urls import reverse_lazy as reverse
 from django.utils.timezone import now
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from ..forms.messages import MessageFilterForm
 from ..models.messages import MessageRecipient
