@@ -1,5 +1,5 @@
 from django.urls import reverse_lazy as reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from ..forms.parent import ParentForm
 from ..models.roles import Parent
