@@ -5,14 +5,14 @@ from django.db.models import Sum
 from django.template.response import TemplateResponse
 from django.urls import reverse_lazy as reverse
 from django.utils.functional import cached_property
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from ...forms.reports.events import EventPaymentsForm, EventPaymentsStatusForm, EventStatsForm
-from ...models.agegroup import AgeGroup
+from ...models.activities import ActivityModel, Payment, RegistrationParticipant
 from ...models.citizenship import Citizenship
 from ...models.events import Event, EventRegistration
 from ...models.roles import Participant
-from ...models.subjects import SubjectPayment, SubjectRegistrationParticipant, SubjectType
+from ...models.statgroup import StatGroup
 from ...views.generic import FormView
 
 
@@ -26,13 +26,13 @@ class ReportEventPaymentsView(FormView):
     def form_valid(self, form):
         context = form.cleaned_data
         context["form"] = form
-        context["received_payments"] = SubjectPayment.objects.filter(
-            target_registration__subject__subject_type__subject_type=SubjectType.EVENT,
+        context["received_payments"] = Payment.objects.filter(
+            target_registration__activity__activity_type__model=ActivityModel.EVENT,
             accounted__gte=context["date_start"],
             accounted__lte=context["date_end"],
         )
-        context["returned_payments"] = SubjectPayment.objects.filter(
-            source_registration__subject__subject_type__subject_type=SubjectType.EVENT,
+        context["returned_payments"] = Payment.objects.filter(
+            source_registration__activity__activity_type__model=ActivityModel.EVENT,
             accounted__gte=context["date_start"],
             accounted__lte=context["date_end"],
         )
@@ -80,7 +80,7 @@ class ReportEventPaymentsStatusView(FormView):
                         status=registration.get_payment_status(self.date),
                     )
                     for registration in EventRegistration.objects.filter(
-                        subject=self.event,
+                        activity=self.event,
                         approved__date__lte=self.date,
                     )
                 )
@@ -99,7 +99,7 @@ class ReportEventStatsView(FormView):
     submit_label = _("Show")
     back_url = reverse("leprikon:report_list")
 
-    ReportItem = namedtuple("ReportItem", ("age_group", "all", "boys", "girls", "citizenships"))
+    ReportItem = namedtuple("ReportItem", ("stat_group", "all", "boys", "girls", "citizenships"))
 
     @lru_cache
     def get_event_days(self, event_id):
@@ -123,18 +123,18 @@ class ReportEventStatsView(FormView):
 
         if approved_later:
             # approved registrations created by the date
-            participants = SubjectRegistrationParticipant.objects.filter(
+            participants = RegistrationParticipant.objects.filter(
                 registration__created__date__lte=d,
                 registration__approved__isnull=False,
             )
         else:
             # registrations approved by the date
-            participants = SubjectRegistrationParticipant.objects.filter(
+            participants = RegistrationParticipant.objects.filter(
                 registration__approved__date__lte=d,
             )
         participants = (
             participants.filter(
-                registration__subject__in=form.cleaned_data["events"],
+                registration__activity__in=form.cleaned_data["events"],
             )
             .exclude(registration__canceled__date__lte=d)
             .select_related("registration", "age_group")
@@ -150,9 +150,9 @@ class ReportEventStatsView(FormView):
             participants = list(participants)
 
         if min_days:
-            participants = [p for p in participants if self.get_event_days(p.registration.subject_id) >= min_days]
+            participants = [p for p in participants if self.get_event_days(p.registration.activity_id) >= min_days]
 
-        context["events_count"] = len(set(participant.registration.subject_id for participant in participants))
+        context["events_count"] = len(set(participant.registration.activity_id for participant in participants))
 
         if unique_participants:
             participants = list({p.key: p for p in participants}.values())
@@ -161,7 +161,7 @@ class ReportEventStatsView(FormView):
         context["citizenships"] = citizenships
 
         context["participants_counts"] = self.ReportItem(
-            age_group=None,
+            stat_group=None,
             all=len(participants),
             boys=len([p for p in participants if p.gender == Participant.MALE]),
             girls=len([p for p in participants if p.gender == Participant.FEMALE]),
@@ -169,12 +169,12 @@ class ReportEventStatsView(FormView):
                 len([p for p in participants if p.citizenship_id == citizenship.id]) for citizenship in citizenships
             ],
         )
-        context["participants_counts_by_age_groups"] = []
-        for age_group in AgeGroup.objects.all():
-            parts = [p for p in participants if p.age_group == age_group]
-            context["participants_counts_by_age_groups"].append(
+        context["participants_counts_by_stat_groups"] = []
+        for stat_group in StatGroup.objects.all():
+            parts = [p for p in participants if p.age_group.stat_group_id == stat_group.id]
+            context["participants_counts_by_stat_groups"].append(
                 self.ReportItem(
-                    age_group=age_group,
+                    stat_group=stat_group,
                     all=len(parts),
                     boys=len([p for p in parts if p.gender == Participant.MALE]),
                     girls=len([p for p in parts if p.gender == Participant.FEMALE]),
