@@ -1,6 +1,6 @@
 from django.http import Http404
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from ..forms.timesheets import TimesheetEntryForm
 from ..models.timesheets import Timesheet, TimesheetEntry
